searchData={"items":[{"type":"module","title":"Bind","doc":"`Bind` provides functionality to build dynamic Ecto queries based on given parameters.\nIt allows developers to retrieve data flexibly without writing custom queries for each use case.","ref":"Bind.html"},{"type":"module","title":"Examples - Bind","doc":"Given an Ecto schema module `MyApp.User` and a map of query parameters, you can build and run a query like this:\n\n    > params = %{ \"name[eq]\" => \"Alice\", \"age[gte]\" => 30, \"sort\" => \"-age\", \"limit\" => \"10\" }\n    > query = Bind.query(MyApp.User, params)\n    > results = Repo.all(query)\n    > IO.inspect(results)","ref":"Bind.html#module-examples"},{"type":"function","title":"Bind.query/2","doc":"Builds an Ecto query for the given schema based on the provided query string.","ref":"Bind.html#query/2"},{"type":"function","title":"Parameters - Bind.query/2","doc":"- `schema`: The Ecto schema module (e.g., `MyApp.User`).\n  - `query_string`: The query string from a URL.","ref":"Bind.html#query/2-parameters"},{"type":"function","title":"Examples - Bind.query/2","doc":"> query_string = \"?name[eq]=Alice&age[gte]=30&sort=-age&limit=10\"\n    > Bind.query(MyApp.User, query_string)\n    #Ecto.Query = ^30, order_by: [desc: u0.age]>","ref":"Bind.html#query/2-examples"},{"type":"module","title":"Bind.Parse","doc":"","ref":"Bind.Parse.html"},{"type":"function","title":"Bind.Parse.constraint/3","doc":"Parses a constraint and returns a dynamic query fragment.","ref":"Bind.Parse.html#constraint/3"},{"type":"function","title":"Parameters - Bind.Parse.constraint/3","doc":"- `field`: The field to apply the constraint to.\n  - `constraint`: The type of constraint (e.g., \"eq\", \"gte\").\n  - `value`: The value to compare the field against.","ref":"Bind.Parse.html#constraint/3-parameters"},{"type":"function","title":"Examples - Bind.Parse.constraint/3","doc":"> Bind.Parse.constraint(:name, \"eq\", \"Alice\")\n    dynamic([r], r.name == ^\"Alice\")\n\n    > Bind.Parse.constraint(:age, \"gte\", 30)\n    dynamic([r], r.age > ^30)","ref":"Bind.Parse.html#constraint/3-examples"},{"type":"function","title":"Bind.Parse.sort_field/1","doc":"Parses the sort parameter to determine the sort direction and field.","ref":"Bind.Parse.html#sort_field/1"},{"type":"function","title":"Parameters - Bind.Parse.sort_field/1","doc":"- `param`: The sort parameter as a string.","ref":"Bind.Parse.html#sort_field/1-parameters"},{"type":"function","title":"Examples - Bind.Parse.sort_field/1","doc":"> Bind.Parse.sort_field(\"-age\")\n    [desc: :age]\n\n    > Bind.Parse.sort_field(\"name\")\n    [asc: :name]","ref":"Bind.Parse.html#sort_field/1-examples"},{"type":"function","title":"Bind.Parse.where_field/1","doc":"Parses a where parameter to extract the field name and constraint.","ref":"Bind.Parse.html#where_field/1"},{"type":"function","title":"Parameters - Bind.Parse.where_field/1","doc":"- `param`: The where parameter as a string.","ref":"Bind.Parse.html#where_field/1-parameters"},{"type":"function","title":"Examples - Bind.Parse.where_field/1","doc":"> Bind.Parse.where_field(\"name[eq]\")\n    [:name, \"eq\"]\n\n    > Bind.Parse.where_field(\"age[gte]\")\n    [:age, \"gte\"]","ref":"Bind.Parse.html#where_field/1-examples"},{"type":"module","title":"Bind.QueryBuilder","doc":"","ref":"Bind.QueryBuilder.html"},{"type":"function","title":"Bind.QueryBuilder.add_limit_query/2","doc":"","ref":"Bind.QueryBuilder.html#add_limit_query/2"},{"type":"function","title":"Bind.QueryBuilder.add_offset_query/2","doc":"","ref":"Bind.QueryBuilder.html#add_offset_query/2"},{"type":"function","title":"Bind.QueryBuilder.build_sort_query/1","doc":"","ref":"Bind.QueryBuilder.html#build_sort_query/1"},{"type":"function","title":"Bind.QueryBuilder.build_where_query/1","doc":"","ref":"Bind.QueryBuilder.html#build_where_query/1"},{"type":"module","title":"Bind.QueryString","doc":"Provides functionality to convert a query string from a URL into a map.","ref":"Bind.QueryString.html"},{"type":"function","title":"Bind.QueryString.to_map/1","doc":"Converts a query string from a URL into a map, converting numerical values to number type.","ref":"Bind.QueryString.html#to_map/1"},{"type":"function","title":"Parameters - Bind.QueryString.to_map/1","doc":"- `query_string`: The query string from a URL.","ref":"Bind.QueryString.html#to_map/1-parameters"},{"type":"function","title":"Examples - Bind.QueryString.to_map/1","doc":"iex> Bind.QueryString.to_map(\"?name[eq]=Alice&age[gte]=30&sort=-age&limit=10\")\n    %{\"name[eq]\" => \"Alice\", \"age[gte]\" => 30, \"sort\" => \"-age\", \"limit\" => 10}","ref":"Bind.QueryString.html#to_map/1-examples"},{"type":"extras","title":"Bind","doc":"# Bind\n\nFlexible and dynamic Ecto query builder for Elixir applications, allowing developers to retrieve data flexibly without writing custom queries for each use case.","ref":"readme.html"},{"type":"extras","title":"Installation - Bind","doc":"Add `bind` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:bind, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"API - Bind","doc":"```ex\nBind.query(schema, params)\n```\n\nParameters:\n\n-   `schema`: The Ecto schema module (e.g., `MyApp.User`).\n-   `params`: Either a map of query parameters or a query string.\n\nReturns: An Ecto query.","ref":"readme.html#api"},{"type":"extras","title":"Usage Example - Bind","doc":"Create Ecto query:\n\n```ex\nquery = Bind.query(MyApp.User, %{ \"name[eq]\" => \"Alice\", \"age[gte]\" => 30 })\n```\n\nAlternatively, with a query string:\n\n```ex\nquery = Bind.query(MyApp.User, \"?name[eq]=Alice&age[gte]=30\")\n```\n\nAnd finally run the query to get results from the database:\n\n```ex\nresults = Repo.all(query)\n```","ref":"readme.html#usage-example"},{"type":"extras","title":"Filtering - Bind","doc":"Example:\n\n```ex\nBind.query(%{\"name[eq]\" => \"Alice\", \"age[gte]\" => 30})\n```\n\nBind supports various comparison operators for filtering:\n\n-   `eq`: Equal to\n-   `neq`: Not equal to\n-   `gt`: Greater than\n-   `gte`: Greater than or equal to\n-   `lt`: Less than\n-   `lte`: Less than or equal to\n-   `true`: Boolean true\n-   `false`: Boolean false\n-   `starts_with`: String starts with\n-   `ends_with`: String ends with\n-   `in`: In a list of values\n-   `contains`: String contains\n-   `nil`: Is nil (or is not nil)","ref":"readme.html#filtering"},{"type":"extras","title":"Sorting - Bind","doc":"Use the `sort` parameter to specify sorting order:\n\n-   Prefix with `-` for descending order\n-   No prefix for ascending order\n\n```ex\nparams = %{\"sort\" => \"-age\"}  # Sort by age descending\n```","ref":"readme.html#sorting"},{"type":"extras","title":"Pagination - Bind","doc":"-   `limit`: Specify the maximum number of results (default: 10)\n-   `start`: Specify the starting ID for pagination\n\nExample:\n\n```ex\nparams = %{\"limit\" => 20, \"start\" => 100}\n```","ref":"readme.html#pagination"},{"type":"extras","title":"Query String Support - Bind","doc":"Bind can also pass URL query strings:\n\n```ex\nquery_string = \"?name[eq]=Alice&age[gte]=30&sort=-age&limit=10\"\nquery = Bind.query(MyApp.User, query_string)\n```","ref":"readme.html#query-string-support"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}